# -*- coding: utf-8 -*-
# Generated by Django 1.10.8 on 2018-02-14 20:01
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('seeker', '0002_auto_20150507_0134'),
    ]

    operations = [
        migrations.AddField(
            model_name='savedsearch',
            name='data',
            field=models.TextField(blank=True),
        ),
        migrations.AddField(
            model_name='savedsearch',
            name='saved',
            field=models.BooleanField(default=False, help_text='This saved search was marked "saved" by the user.'),
        ),
        migrations.AlterField(
            model_name='savedsearch',
            name='name',
            field=models.CharField(blank=True, max_length=100),
        ),
    ]
