<div class="progress" style="margin-bottom:0;" title="{{ percentile }}&#37; percentile">
    <div class="progress-bar" style="width:{{ percentile }}%;"></div>
</div>
<span class="sr-only">{{ percentile }}&#37; percentile</span>
