{% load i18n %}

<div class="page-header">
    <div id="saved-search-header">
        {% block saved-search-header-content %}
            <h3 class="saved-search-name"></h3>
        {% endblock saved-search-header-content %}
    </div>
</div>
